==> aroundme_0_5_0.tar.tgz: aroundme_0_5_0/aroundme/language/1/barnraiser_01/node_group.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of aroundme
//
// Copyright (C) 2003, 2005 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
// 02111-1307, USA.
// -----------------------------------------------------------------------

require_once($languagePath . 'node_common.lang.php');

//All language vars should be ordered TYPE, A-Z for convenience
//Tom Calthrop - 20th April 2004 (tom@barnraiser.org)
//

//SECTION TITLES
$lang['section_groups'] = 						"groups";
$lang['section_group'] = 						"group details";


//SUBMIT BUTTONS
$lang['sub_update_group'] = 					"update group";


//HREF
$lang['href_go_to_group'] = 					"go to group";
$lang['href_edit_group'] = 						"edit group";
$lang['href_list'] = 							"list groups";


//BODY TEXTS
$lang['txt_election_date'] = 					"election date";
$lang['txt_type'] = 							"type";
$lang['txt_group'] = 							"group";
$lang['txt_members'] = 							"members";
$lang['txt_status'] = 							"status";
$lang['txt_create_date'] = 						"create date";
$lang['txt_registration_group_type'] = 			"registration type";
$lang['txt_title'] =							"title";
$lang['txt_age_from'] = 						"from age";
$lang['txt_age_to'] = 							"to age";
$lang['txt_age_any'] = 							"any";
$lang['txt_synopsis'] = 						"synopsis";
$lang['txt_language'] = 						"preferred language";
$lang['txt_age'] = 								"recommended age";
$lang['txt_group_id'] = 						"id";
$lang['txt_group_create_datetime'] = 			"creation date";
$lang['txt_group_author'] = 					"author";
$lang['txt_default_image'] = 					"default image";
$lang['txt_visibility'] = 						"visibility";
$lang['txt_file_allocation'] = 					"disk allocation";
$lang['txt_rules'] = 							"rules";

//$lang['txt_genre'] = 							"genre";
//$lang['txt_cms_level'] = 						"cms level";
?>

==> aroundme_0_6_2.tar.tgz: aroundme_0_6_2/aroundme/language/1/barnraiser_01/node_group.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of AROUNDMe
//
// Copyright (C) 2003, 2006 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------

require_once($languagePath . 'common.lang.php');



//SECTION TITLES
$lang['hdr_groups'] = 							"groups";
$lang['hdr_group'] = 							"group details";
$lang['hdr_menu'] = 							"menu";

//SUBMIT BUTTONS
$lang['sub_update_group'] = 					"update group";


//HREF
$lang['href_go_to_group'] = 					"go to group";
$lang['href_edit_group'] = 						"edit group";
$lang['href_list_groups'] = 					"list groups";
$lang['href_view_group'] = 						"view group";


//BODY TEXTS
$lang['txt_type'] = 							"type";
$lang['txt_group'] = 							"group";
$lang['txt_members'] = 							"members";
$lang['txt_status'] = 							"status";
$lang['txt_create_date'] = 						"create date";
$lang['txt_registration_group_type'] = 			"registration type";
$lang['txt_title'] =							"title";
$lang['txt_age_from'] = 						"from age";
$lang['txt_age_to'] = 							"to age";
$lang['txt_age_any'] = 							"any";
$lang['txt_synopsis'] = 						"synopsis";
$lang['txt_language'] = 						"preferred language";
$lang['txt_age'] = 								"recommended age";
$lang['txt_group_id'] = 						"id";
$lang['txt_group_create_datetime'] = 			"creation date";
$lang['txt_group_author'] = 					"author";
$lang['txt_default_image'] = 					"default image";
$lang['txt_visibility'] = 						"visibility";
$lang['txt_file_allocation'] = 					"disk allocation";
$lang['txt_rules'] = 							"rules";

?>
